summaryrefslogtreecommitdiff
path: root/include/http_config.h
diff options
context:
space:
mode:
authorRuediger Pluem <rpluem@apache.org>2010-11-10 12:09:27 +0000
committerRuediger Pluem <rpluem@apache.org>2010-11-10 12:09:27 +0000
commit38064564e91a34da75a9f575a6d779c0102f741e (patch)
treeac0139ab1c55474627d2c936ed354ced0f9ab2ee /include/http_config.h
parentc1eb6aa42ae4406c4fbcc75ecbcf1a366bb362e4 (diff)
downloadhttpd-38064564e91a34da75a9f575a6d779c0102f741e.tar.gz
* Fix parameter name as new is a reserved word in C++ which makes compiling
of http_config.h with C++ impossible. PR: 50243 git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@1033427 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/http_config.h')
-rw-r--r--include/http_config.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/http_config.h b/include/http_config.h
index a2f6470613..47a90cc546 100644
--- a/include/http_config.h
+++ b/include/http_config.h
@@ -999,11 +999,11 @@ AP_DECLARE(struct ap_logconf *) ap_new_log_config(apr_pool_t *p,
/**
* Merge old ap_logconf into new ap_logconf.
* old and new must have the same life time.
* @param old The ap_logconf to merge from
* @param new The ap_logconf to merge into
*/
-AP_DECLARE(void) ap_merge_log_config(const struct ap_logconf *old,
- struct ap_logconf *new);
+AP_DECLARE(void) ap_merge_log_config(const struct ap_logconf *old_conf,
+ struct ap_logconf *new_conf);
/* For http_connection.c... */
/**
@@ -999,11 +999,11 @@ AP_DECLARE(struct ap_logconf *) ap_new_log_config(apr_pool_t *p,
* Merge old ap_logconf into new ap_logconf.
* old and new must have the same life time.
- * @param old The ap_logconf to merge from
- * @param new The ap_logconf to merge into
+ * @param old_conf The ap_logconf to merge from
+ * @param new_conf The ap_logconf to merge into
*/